SystemOrganization addCategory: #'VolunteerShowcase-Tests'!

TestCase subclass: #TestOffer
	instanceVariableNames: 'volun1 offer1 task1 task2 task3 skill1 skill2 skill3 coordinator project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerShowcase-Tests'!

!TestOffer commentStamp: 'RG 10/22/2012 18:48' prior: 0!
Testcases for Offer!

!TestOffer methodsFor: 'running' stamp: 'MGH 10/17/2012 17:14'!
setUp
	"set up test environment"
	
	CollectionSingleton reset.
	TaskCollection reset.
	CoordinatorCollection reset.
	ProjectCollection reset.
	SkillCollection reset.
	VolunteerCollection reset.

      coordinator := Coordinator new.
	coordinator name: 'Bruno' ;
				 email: 'collaco.bruno@gmail.com' ;
				 organization: 'IAG-USP'.
				
	project := ProjectX new.	
	project name: 'Weekend Classes' ;
		      description: 'This project aims to help students by giving extra classes on the weekends' ;
		      type: 'Extra Classes'. 
      project addCoordinator: coordinator.

	skill1 := Skill new.	
	skill1 name: 'Math Teacher' ;
		  description: 'to give classes of maths'. 
      skill1 save.
		
	skill2 := Skill new.	
	skill2 name: 'Phisics Teacher' ;
		  description: 'to give classes of phisics'.
      skill2 save.
		
	skill3 := Skill new.	
	skill3 name: 'Computation Teacher' ;
		  description: 'to give classes of computation'.
      skill3 save.
		
	volun1 := Volunteer new.
	volun1 createAccount: 'bruno' pass: 'bbc' name: 'Bruno'  email: 'collaco.bruno@gmail.com'                    photo: '' birthday: '1986-11-5'.
	volun1 save.
				
	offer1 := Offer new.	
			
	task1 := Task new.	
	task1 name: 'Give Math Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task1 addSkill: skill1.
      task1 save.

	task2 := Task new.	
	task2 name: 'Give Phisics Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task2 addSkill: skill2.
      task2 save.

	task3 := Task new.	
	task3 name: 'Give Computation Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task3 addSkill: skill3.
      task3 save.

      project addTask: task1.
      project addTask: task2.
      project addTask: task3.
      project save.! !

!TestOffer methodsFor: 'testing' stamp: 'MGH 10/22/2012 11:19'!
testChangeState
	"Coordinator changes the state of a task"

	coordinator ChangeState: task1 status: 'Running'.
	self assert: (task1 status = 'Running').
! !

!TestOffer methodsFor: 'testing' stamp: 'MGH 10/17/2012 17:36'!
testCoordinatorResponse
	"coordinator responses the offer"
	|offer col|
	volun1 addSkill: skill1.
      volun1 addSkill: skill2.
      col:= volun1 suggestions.	
	volun1 SendOffer: (col at: 1) message: 'I want to do this task'.
      offer := (coordinator inbox) at: 1.
	coordinator ReviseOffer: offer message: 'Ok.' accepted: true.	
	self assert: ((task1 volunteers) size =1).
! !

!TestOffer methodsFor: 'testing' stamp: 'MGH 10/22/2012 11:20'!
testCoordinatorSendOffer
	"coordinator sends an offer"
	|voluns Vol1|
      voluns := task1 getListOfVolunteers: ((VolunteerCollection default) collection).
      Vol1 := voluns at: 1.
      coordinator SendOffer: task1 message: 'Do you want to do this task?' volunteer: Vol1.
	self assert: ((Vol1 inbox) size =1).
! !

!TestOffer methodsFor: 'testing' stamp: 'MGH 10/22/2012 11:22'!
testTaskSuggestions
	"coordinator views the volunteers that can do a task"
	|voluns|
      voluns := task1 getListOfVolunteers: ((VolunteerCollection default) collection).
	self assert: (voluns size =1).
! !

!TestOffer methodsFor: 'testing' stamp: 'MGH 10/22/2012 11:22'!
testVolunteerOfferSomeTask
	"Volunteer views the tasks that can do, and send an offer"
	|col|
      volun1 addSkill: skill1.
      volun1 addSkill: skill2.
      col:= volun1 suggestions.	
	volun1 SendOffer: (col at: 1) message: 'I want to do this task'.
	self assert: ((coordinator inbox) size =1).
! !

!TestOffer methodsFor: 'testing' stamp: 'MGH 10/22/2012 11:23'!
testVolunteerResponse
	"coordinator sends and offer and the volunteer responses the offer"
	|voluns Vol1 offer|
      voluns := task1 getListOfVolunteers: ((VolunteerCollection default) collection).
      Vol1 := voluns at: 1.
      coordinator SendOffer: task1 message: 'Do you want to do this task?' volunteer: Vol1.
      offer := (Vol1 inbox) at: 1.
      Vol1 responseOffer: 'Yes. I want' offer: offer accepted: true.
      Transcript cr; show: ((Vol1 inbox) size) printString.
	self assert: ((Vol1 inbox) size =0).
! !

!TestOffer methodsFor: 'testing' stamp: 'MGH 10/17/2012 17:30'!
testVolunteerSkills
	"Volunteer adds skills"
      volun1 addSkill: skill1.
      volun1 addSkill: skill2.

 	self assert: ((volun1 skills) size =2).
! !

!TestOffer methodsFor: 'testing' stamp: 'MGH 10/22/2012 11:25'!
testVolunteerSuggestion
	"Volunteer views the tasks that can do"
	|col|
      volun1 addSkill: skill1.
      volun1 addSkill: skill2.

      col:= volun1 suggestions.	
	self assert: (col size =2).
! !

TestCase subclass: #TestProject
	instanceVariableNames: 'aUser aCoordinator aProject aTask'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerShowcase-Tests'!

!TestProject commentStamp: 'RG 10/22/2012 18:49' prior: 0!
Testcases involving ProjectX!

!TestProject methodsFor: 'running' stamp: 'BBC 10/22/2012 14:29'!
setUp
	"Creating variables for the tests"
	aUser := User new.
	aUser name: 'Mijail222' ;
	          login: 'exmija';
                password: '1234'.
	
	aCoordinator := Coordinator new.
	aCoordinator name: 'Renzo222';
	                     login: 'rgomez';
	                     password: '12345'.
	
	aProject := ProjectX new.	
	aProject name: 'Weekend Classes';
			  description: 'This project aims to help students by giving extra classes on the weekends' ;
		        type: 'Extra Classes'.
		
	aTask := Task new.	
	aTask name: 'Give Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40.  	
	
	"Reset database collections"
	VolunteerCollection reset.
	ProjectCollection reset.
	AdminCollection reset.
	TaskCollection reset.
	SkillCollection reset! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:18'!
testAddCoordinator
	"Testing that a coordinatoor of a project
	  can add other coordinators"
	| project |
	"Creating test project"
	project := ProjectX new.
	project name: 'Test Project 2'.
	"Setting aUser as creator (first coordinator) of project"
	project setCoordinator: aUser.
	project save.
	"Testing that aUser is a coordinator"
	self
		assert: (project isCoordinator: aUser).
	"Testing that aCoordinator isn't a coordinator of project"	
	self assert: (project isCoordinator: aCoordinator)
			= false.
	"Testing that aUser can add a coordinator to a project"
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project addCoordinator: aCoordinator].
	"Testing that aCoordinator was addded to coordinator's list of project"	
	self
		assert: (project isCoordinator: aCoordinator)! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:29'!
testAddTask
	"Testing that a coodinator can add a task to his projects"
	| project aTask instance |
	"Creating a project"
	project := ProjectX new.
	project name: 'Test Project 3'.
	self assert: (project isCoordinator: aUser)
			= false.
	project setCoordinator: aUser.
	project save.
	"Testing that aUser is coordinator of project"
	self
		assert: (project isCoordinator: aUser).
	"Creating a task"	
	aTask := Task new.
	aTask name: 'Task 1'.
	aTask save.
	instance := TaskCollection default.
	"Testing that aTask was properly saved on database"
	self
		assert: (instance hasObject: aTask).
	"Testing that aUser can add a task to the project"	
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project addTask: aTask].
	"Testing that aTask was added to project"	
	self
		assert: (project tasks includes: aTask)! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:37'!
testAddTaskFailure
	"Testing that user that isn't an admin or coordinator of a project can't add a task"
	| project aTask instance |
	"Creating project"
	project := ProjectX new.
	project name: 'Test Project 3'.
	"Testing that aUser isn't coordinator of project"
	self assert: (project isCoordinator: aUser)
			= false.
			
	project save.
	"Creating a task"
	aTask := Task new.
	aTask name: 'Task 1'.
	aTask save.
	instance := TaskCollection default.
	self
		assert: (instance hasObject: aTask).
	"Test if aUser can add a task"	
	(OperationValidator modifyProject: project user: aUser) ifTrue: 
		[project addTask: aTask.].
	"Test that aTask wasn't added"
	self
		assert: ((project tasks includes: aTask) = false)! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:44'!
testAdminAddTask
	"Testing that a coordinator can add tasks to his projects"
	| project aTask instance anAdmin |
	"Creating project"
	project := ProjectX new.
	project name: 'Test Project 3'.
	"Creating anAdmin from aUser (making aUser part of Admins)"
	anAdmin := Admin new.
	anAdmin setFromUser: aUser.
	anAdmin save.
	instance := AdminCollection default.
	"Testing that anAdmin was saved in database"
	self
		assert: (instance hasObject: anAdmin).
	project save.
	"Testing that aUser isn't coordinator of project"
	self assert: (project isCoordinator: aUser)
			= false.
	"Creating a task"		
	aTask := Task new.
	aTask name: 'Task 1'.
	aTask save.
	instance := TaskCollection default.
	"Testing that aTask was properly saved in Task's database"
	self
		assert: (instance hasObject: aTask).
	"Testing if aUser can add a task to project"	
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project addTask: aTask].
	"Testing thar aTask was added to project"	
	self
		assert: (project tasks includes: aTask)! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:45'!
testCreatingProject
	"check if the project collection has a project recently added"

	| pc | 
	aProject save.
	pc := ProjectCollection default.
	
	self assert: (pc hasProject: aProject).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:46'!
testIfProjectHasCoordinator
	"check if a project has a coordinator"

	aProject addCoordinator: aCoordinator.

	self assert: (aProject hasCoordinator: aCoordinator).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:47'!
testIfProjectHasTask
	"tests adding a task to the project"

	| project task | 
	
	project:= ProjectX new.
	task := Task new.

	project addTask: task.

	self assert: (project hasTask: task).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:48'!
testIfProjectHasVolunteer
	"tests adding a volunteer to the task and consequently to the project"

	| aVolunteer |
	
	aVolunteer := Volunteer new.
	aTask addVolunteer: aVolunteer.
	aProject addTask: aTask.

	self assert: (aProject hasVolunteer: aVolunteer).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:48'!
testProjectAddComment
	"addind a comment to the project"

	| project comment result | 
	
	project := ProjectX new.
	comment := Comment new.
	
	comment message: 'This is a comment of the project'.
	result := project addComment: comment.
	project comments.

	self assert: (result).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:52'!
testProjectEndDate
	"when a project finishes, its end date is set to current day."

	
	| project |

	project := ProjectX new.
	
	project status: 'Finished'.

	self assert: (project endDate = Date today).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:52'!
testProjectRemoveComment
	"removing a comment"

	| aComment | 
	
	aComment := Comment new.
	aComment message: 'message bla !!'.
	aProject addComment: aComment.
	

	self assert: (aProject removeComment: aComment)

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:53'!
testProjectStatusChanges
	"if all project's tasks finishes, then the project also finishes."

	| p1 t1 shift result | 
	
	result := true.
	
	p1 := ProjectX new.
	t1 := Task new.
	
	(p1 status = 'Open') 
		ifTrue:  [shift := true]
		ifFalse: [shift := false. result := false.].
	
	p1 addTask: t1.
	
	t1 status: 'Finished'.
	
	(p1 status = 'Finished') 
		ifTrue:  [shift := true]
		ifFalse: [shift := false. result := false.].
	
	
	self assert: (result).

				
				
	! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:57'!
testProjectXCreation
	"Testing project creation"
	| project instanceProject instanceCoordinator |
	"Creating a project"
	project := ProjectX new.
	project name: 'Test project'.
	project setCoordinator: aUser.
	"Saving project to ProjectX's database"
	project save.
	instanceProject := ProjectCollection default.
	instanceCoordinator := CoordinatorCollection default.
	"Testing thar project was saved to database"
	self
		assert: (instanceProject hasObject: project).
	"Testing that project's creator is settled to it's first coordinator 
	  (Added to coordinator's database)"
	self
		assert: (instanceCoordinator hasObject: aUser)! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:48'!
testRemoveTaskAdmin
	"Testing that an Admin can remove a task from any project"
	| project aTask anAdmin |
	"Creating a project"
	project := ProjectX new.
	project name: 'Test Project 5'.
	project save.
	"Making aUser an Admin"
	anAdmin := Admin new.
	anAdmin setFromUser: aUser.
	anAdmin save.
	"Testing that aUser isn't a coordinator of project"
	self assert: (project isCoordinator: aUser)
			= false.
	"Creating a task"		
	aTask := Task new.
	aTask name: 'Task 3'.
	project addTask: aTask.
	"Testing if aUser can remove a task from project"
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project removeTask: aTask].
	"Testing that aTask was removed"	
	self assert: (project tasks includes: aTask)
			= false! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:51'!
testRemoveTaskCoordinator
	"Testing that a coordinator can remove a task from his projects"
	| project aTask |
	"Creating project"
	project := ProjectX new.
	project name: 'Test Project 4'.
	project setCoordinator: aUser.
	project save.
	"Testing that aUser is coordinator of project"
	self
		assert: (project isCoordinator: aUser).
	"Creating a task"	
	aTask := Task new.
	aTask name: 'Task 2'.
	project addTask: aTask.
	"Test if aUser can remove a task from project"
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project removeTask: aTask].
	"Testing thar aTask was removed from project"	
	self assert: (project tasks includes: aTask)
			= false! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:54'!
testRemoveTaskFailure
	"Test that a user that isn't a coordinator of a project or admin can't
	  remove a task"
	| project aTask |
	"Creating project"
	project := ProjectX new.
	project name: 'Test Project 5'.
	project save.
	"Testing that aUser isn't project's coordinator"
	self assert: (project isCoordinator: aUser)
			= false.
	"Creating a task"
	aTask := Task new.
	aTask name: 'Task 3'.
	project addTask: aTask.
	"Testing if aUser can remove a task from project"
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project removeTask: aTask].
	"Testing that aTask wasn't removed"
	self
		assert: (project tasks includes: aTask)! !

TestCase subclass: #TestShowInfo
	instanceVariableNames: 'volun1 offer1 task1 task2 task3 skill1 skill2 skill3 coordinator project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerShowcase-Tests'!

!TestShowInfo commentStamp: 'RG 10/22/2012 18:49' prior: 0!
Test for showing information!

!TestShowInfo methodsFor: 'testing' stamp: 'RG 10/22/2012 19:18'!
ShowInfoProject: aProject
	"show information of the project"
	|size i tasks task templinha|
	tasks := aProject tasks.
      size := tasks size.
      i := 1.
	Transcript cr.
	Transcript cr; show: 'Show formation for projects'; cr.
	Transcript show: '==================='; cr.
      Transcript show: 'Name             '.     
      Transcript show: 'Status      '.
	Transcript show: 'Depends on      '.
	Transcript show: 'Volunteers'.
      [[ i <= size ] whileTrue: 
        [ task:=tasks at: i.
          templinha := String new.
	    templinha := templinha, (task name) asString.
	    templinha := templinha,  Character tab asString,  Character tab asString.
	    templinha := templinha,  (task status) asString.
	    templinha := templinha,  Character tab asString.
	    templinha := templinha,  (task StrDepends) asString.
	    templinha := templinha,  Character tab asString.
	    templinha := templinha,  (task StrVolunteers) asString.
	    Transcript cr; show: templinha contents.
          i:=i+1.].]
      on: Exception
			do: [:ex | ^false. ].
	Transcript cr.
	            ^true
	! !

!TestShowInfo methodsFor: 'testing' stamp: 'RG 10/22/2012 19:19'!
ShowTasksProject: aProject
	"show information of the project"
	|size i tasks task templinha|
	tasks := aProject tasks.
      size := tasks size.
      i := 1.
	Transcript cr.
	Transcript cr; show: 'Showing information for Tasks'.
	Transcript cr; show: '====================='.
      Transcript cr; show: 'Name                     StartDate           EstimatedTime'.
      [[ i <= size ] whileTrue: 
        [ task:=tasks at: i.
          templinha := String new.
	    templinha := templinha, (task name) asString.
	    templinha := templinha,  Character tab asString.
	    templinha := templinha, (task startDate) asString.
	    templinha := templinha, Character tab asString.
	    templinha := templinha, (task estimatedTime) asString.
	    Transcript cr; show: templinha contents.
          i:=i+1.].]
      on: Exception
			do: [:ex | ^false. ].
	Transcript cr.
	            ^true! !

!TestShowInfo methodsFor: 'running' stamp: 'MGH 10/22/2012 13:30'!
setUp
	"set up test environment"
	
	CollectionSingleton reset.
	TaskCollection reset.
	CoordinatorCollection reset.
	ProjectCollection reset.
	SkillCollection reset.
	VolunteerCollection reset.

      coordinator := Coordinator new.
	coordinator name: 'Bruno' ;
				 email: 'collaco.bruno@gmail.com' ;
				 organization: 'IAG-USP'.
				
	project := ProjectX new.	
	project name: 'Weekend Classes' ;
		      description: 'This project aims to help students by giving extra classes on the weekends' ;
		      type: 'Extra Classes'. 
      project addCoordinator: coordinator.

	skill1 := Skill new.	
	skill1 name: 'Math Teacher' ;
		  description: 'to give classes of maths'. 
      skill1 save.
		
	skill2 := Skill new.	
	skill2 name: 'Phisics Teacher' ;
		  description: 'to give classes of phisics'.
      skill2 save.
		
	skill3 := Skill new.	
	skill3 name: 'Computation Teacher' ;
		  description: 'to give classes of computation'.
      skill3 save.
		
	volun1 := Volunteer new.
	volun1 createAccount: 'bruno' pass: 'bbc' name: 'Bruno'  email: 'collaco.bruno@gmail.com'                    photo: '' birthday: '1986-11-5'.
	volun1 save.
				
	offer1 := Offer new.	
			
	task1 := Task new.	
	task1 name: 'Give Math Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task1 addSkill: skill1.
      task1 addVolunteer: volun1.
      task1 save.

	task2 := Task new.	
	task2 name: 'Give Phisics Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task2 addSkill: skill2.
      task2 dependsOn: task1.
      task2 save.

	task3 := Task new.	
	task3 name: 'Give Computation Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task3 addSkill: skill3.
      task3 save.

      project addTask: task1.
      project addTask: task2.
      project addTask: task3.
      project save.! !

!TestShowInfo methodsFor: 'testing' stamp: 'MGH 10/22/2012 13:22'!
testShowInfoProject
	"show the tasks of a project, with the volunteers and dependences"

	self assert: (self ShowInfoProject: project).
! !

!TestShowInfo methodsFor: 'testing' stamp: 'MGH 10/22/2012 13:22'!
testShowTasksProject
	"show the tasks of a project with the start date and the estimated time"

	self assert: (self ShowTasksProject: project).
! !

TestCase subclass: #TestSkill
	instanceVariableNames: 'aUser aSkill'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerShowcase-Tests'!

!TestSkill commentStamp: 'RG 10/22/2012 18:49' prior: 0!
Tescases for Skill!

!TestSkill methodsFor: 'running' stamp: 'RG 10/21/2012 16:05'!
setUp
	"Reseting database collections"
	VolunteerCollection reset.
	ProjectCollection reset.
	AdminCollection reset.
	TaskCollection reset.
	SkillCollection reset.
	"Creating variables for the test"
	aUser := User new.
	aUser name: 'Mijail11'.
	aUser login: 'exmija'.
	aUser password: '1234'.
	
	aSkill := Skill new.
	aSkill name: 'Test Skill'.
	aSkill description: 'Test'! !

!TestSkill methodsFor: 'testing' stamp: 'RG 10/21/2012 16:04'!
testCreateSkill
	"Testing that an admin can add skills to the system"
	| instance |
	
	instance := SkillCollection default.
	"Testing that aUser can't add a skill to the system"
	self assert: (OperationValidator addSkill: aUser)
			= false.
			
	"Testing that skills database doesn'r contain aSkill"		
	self assert: (instance hasObject: aSkill)
			= false.
	
	"Adding aUser to Admin's database"
	instance := AdminCollection default.
	instance addAdmin: aUser.
	"Testing that aUser now can add a skill to the system"
	(OperationValidator addSkill: aUser) ifTrue: 
		[aSkill save.].
	"Testing that aSkill was saved in database"
	instance := SkillCollection default.
	self
		assert: (instance hasObject: aSkill)! !

!TestSkill methodsFor: 'testing' stamp: 'RG 10/22/2012 18:46'!
testCreateSkillFailure
	"Testing that users that aren't admins can't add a skill to the system"
	| instance |
	
	instance := SkillCollection default.			
	"Testing that skills database doesn'r contain aSkill"		
	self assert: (instance hasObject: aSkill)
			= false.
	"Testing if aUser can add a skill to the system"
	(OperationValidator addSkill: aUser) ifTrue: 
		[aSkill save.].
	"Testing that aSkill wasn't added"
	instance := SkillCollection default.
	self
		assert: ((instance hasObject: aSkill) = false).! !

TestCase subclass: #TestTask
	instanceVariableNames: 'aProject aCoordinator aTask'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerShowcase-Tests'!

!TestTask commentStamp: 'RG 10/22/2012 18:50' prior: 0!
Testcases involving Task!

!TestTask methodsFor: 'running' stamp: 'RG 10/21/2012 15:11'!
setUp
	"Reset the database collections"
	ProjectCollection reset.
	TaskCollection reset.
	AdminCollection reset.
	CoordinatorCollection reset.
	SkillCollection reset.
	"Creating a coordinator for aProject"
	aCoordinator := Coordinator new.
	aCoordinator name: 'Test Coordinator'.
	"Creating aProject"
	aProject := ProjectX new.
	aProject name: 'Test Project 5'.
	"Creating a task for aProject"
	aTask := Task new.
	aTask name: 'Test Task'.
	
	aProject addCoordinator: aCoordinator.
	aProject addTask: aTask! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/21/2012 14:49'!
testAddSkillCoordinator
	"Testing the addition of a skill to a task"
	| aSkill |
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	"Testing if aTask is part of aProject (both variables were created in setUp method)"
	self
		assert: (aProject tasks includes: aTask).
	"Testing that aSkill isn't part of the aTask skills "	
	self assert: ((aTask hasSkill: aSkill) = false).
	"Testing the aCoordinator can add skill to a project's tasks"		
	(OperationValidator modifyProject: aProject user: aCoordinator)
		ifTrue: [aTask addSkill: aSkill].
	"Testing that aSkill was properly added"	
	self
		assert: (aTask hasSkill: aSkill)! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:55'!
testCreatingTask
	"check if the task collection has a task recently added"

	| tc | 
	aTask save.
	tc := TaskCollection default.
	
	self assert: (tc hasTask: aTask).

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:55'!
testIfTaskEstimatedTime
	"adding the estimeated time (hours) of a task as an integer"

	aTask estimatedTime: 100.

	self assert: (aTask estimatedTime = 100).

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:56'!
testIfTaskHasSkill
	"check if a task has a skill recently added"

	| aSkill | 
	aSkill := Skill new.
	aSkill name: 'Skill_1'.
	aTask addSkill: aSkill.

	self assert: (aTask hasSkill: aSkill).

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:56'!
testIfTaskHasVolunteer
	"check if a task has a volunteer recently added"

	| aVolunteer | 
	aVolunteer := Volunteer new.
	aVolunteer name: 'Volunteer_1'.
	aTask addVolunteer: aVolunteer.

	self assert: (aTask hasVolunteer: aVolunteer).

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:57'!
testIfTaskIsFromAnyProject
	"check from which project a task is"

	aProject addTask: aTask.

	self deny: (aTask fromProject = nil).

				
				
	! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/21/2012 14:55'!
testRemoveSkillAdmin
	"Testing that an Admin can remove a skill"
	| aSkill anAdmin |
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	aTask addSkill: aSkill.
	"Testing that aSkill was properly added"
	self
		assert: (aTask hasSkill: aSkill).
	"Creating an Admin"	
	anAdmin := Admin new.
	anAdmin name: 'Test Admin'.
	anAdmin save.
	"Testing if an Admin can remove a skill"
	(OperationValidator modifyProject: aProject user: anAdmin)
		ifTrue: [aTask removeSkill: aSkill].
	"Testing that aSkill was removed"
	self assert: ((aTask hasSkill: aSkill) = false).
	
	AdminCollection reset! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/21/2012 15:06'!
testRemoveSkillCoordinator
	"Testing that the coordinator of a project can remove a skill of a task "
	| aSkill |
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	aTask addSkill: aSkill.
	"Testing that aSkill was properly added"
	self
		assert: (aTask hasSkill: aSkill).
	"Testing that aCoordinator can remove a skill from a task"	
	(OperationValidator modifyProject: aProject user: aCoordinator)
		ifTrue: [aTask removeSkill: aSkill].
	"Testing that aSkill was removed"	
	self assert: ((aTask hasSkill: aSkill) = false)! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/21/2012 15:10'!
testRemoveSkillFailure
	"Testing that a user that isn't an admin or a coordinator of the project 
	  can't remove a skill from a task"
	| aSkill aUser |
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	aTask addSkill: aSkill.
	"Testing that aSkill was properly added to aTask"
	self
		assert: (aTask hasSkill: aSkill).
	"Creating a dummy user"
	aUser := User new.
	aUser name: 'Test User'.
	"Testing if aUser can remove a skill"
	(OperationValidator modifyProject: aProject user: aUser)
		ifTrue: [aTask removeSkill: aSkill].
	"Testing that aSkill wasn't removed"
	self
		assert: (aTask hasSkill: aSkill)! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:57'!
testTaskAddComment
	"adding a comment to the task"

	| aComment result |
	
	aComment := Comment new.
	aComment message: 'This is a comment of the task'.
	result := aTask addComment: aComment.
	aTask comments.
	

	self assert: (result)

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:58'!
testTaskBecomeFrozen
	"if a task has any dependences that are open, then the task becomes frozen, waiting for its dependences to finish"

	| firstTask|
	
	firstTask := Task new.
	firstTask name: 'Needed Task'.
	
	aTask dependsOn: firstTask.
	
	self assert: ((aTask status) = 'Frozen').

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:59'!
testTaskDependences
	"if all task dependences changes their status to finished, then the dependent task becomes opened."

	| firstTask secondTask shift |
	
	shift := false.
	
	firstTask := Task new.
	firstTask name: 'First Task'.
	
	secondTask := Task new.
	secondTask name: 'Second Task'.
	
	firstTask dependsOn: secondTask.
	((firstTask status) = 'Frozen') ifTrue: [shift := true]. 
	
	secondTask status: 'Finished'.
	((firstTask status) = 'Open') ifFalse: [shift := false]. 
	
	
	
	self assert: (shift)

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 15:00'!
testTaskEndDate
	"if a task's status is set to finished, then its end date becomes the current day."

	| t1 |
	
	t1 := Task new.


	t1 status: 'Finished'.

	self assert: (t1 endDate = Date today).

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 15:00'!
testTaskRemoveComment
	"removing a comment from a task"

	| aComment | 
	
	aComment := Comment new.
	aComment message: 'message bla !!'.
	aTask addComment: aComment.
	

	self assert: (aTask removeComment: aComment)

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 15:01'!
testTaskStartDate
	"when a task is created, its start date is set to the curent day"


	self assert: (aTask startDate = Date today).

				
				
	! !

TestCase subclass: #TestUser
	instanceVariableNames: 'project user aCoordinator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerShowcase-Tests'!

!TestUser commentStamp: 'RG 10/22/2012 18:50' prior: 0!
Tescases for User!

!TestUser methodsFor: 'running' stamp: 'BBC 10/22/2012 14:41'!
setUp
	"Reset the database collections"
	VolunteerCollection reset.
	ProjectCollection reset.
	AdminCollection reset.
	TaskCollection reset.
	SkillCollection reset.
	Comment reset.
	"Creating the project that will include the comment"
	project := ProjectX new.
	project name: 'Test Project 4'.
	project save.
	"Setting the user of the comment"
	user := User new.
	user name: 'Renzo333'.
	user login: 'rgomez'.
	user password: '1234'.
	"Creating a coordinator"
	aCoordinator := Coordinator new.
	aCoordinator name: 'Renzo222';
	                     login: 'rgomez';
	                     password: '12345'.
	

! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:21'!
testAddComment
	"Test the addition of a comment to a project"
	| aComment |
	aComment := Comment new.
	aComment user: user.
	"user and project where created in the setUp method"
	project addComment: aComment.
	self
		assert: (project comments includes: aComment)! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:21'!
testCreateUser
	"Test User creation"
	| aUser volunteer instance |
	aUser := User new.
	aUser name: 'Foo'.
	aUser login: 'bar'.
	aUser password: '1234'.
	volunteer := Volunteer new.
	volunteer setFromUser: aUser.
	volunteer save.
	instance := VolunteerCollection default.
	self
		assert: (instance hasObject: volunteer)! !

!TestUser methodsFor: 'creating' stamp: 'BBC 10/22/2012 15:02'!
testCreatingCoordinator
	"check if the coordinator collection has a coordinator recently added."

	| cc | 
	aCoordinator save.
	cc := CoordinatorCollection default.
	
	self assert: (cc hasCoordinator: aCoordinator).

				
				
	! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:24'!
testRemoveCommentAdmin
	"Test that an Admin can remove any comment"
	| anAdmin aComment |
	anAdmin := Admin new.
	anAdmin name: 'Test'.
	anAdmin login: 'test'.
	anAdmin password: '12345'.
	anAdmin save.
	aComment := Comment new.
	aComment user: user.
	project addComment: aComment.
	"Test that the comment was added successfully"
	self
		assert: (project comments includes: aComment).
	"Testing if the Admin can modify anything in the project"
	(OperationValidator
			modifyComment: aComment
			project: project
			user: anAdmin)
		ifTrue: [project removeComment: aComment].
	"Testing if comment was deleted"	
	self assert: ((project comments includes: aComment) = false)! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:27'!
testRemoveCommentCoordinator
	"Test that a coordinator of a project
	  can remove a comment from that project"
	| aCoordinator aComment |
	aCoordinator := Coordinator new.
	aCoordinator name: 'Brunp'.
	aCoordinator login: 'bruno'.
	aCoordinator password: '12345'.
	project addCoordinator: aCoordinator.
	aComment := Comment new.
	aComment user: user.
	project addComment: aComment.
	"Testing that comment was properly added"
	self
		assert: (project comments includes: aComment).
	"Testing if aCoordinator can remove that comment"
	(OperationValidator
			modifyComment: aComment
			project: project
			user: aCoordinator)
		ifTrue: [project removeComment: aComment].
	"Testing that comment was removed"	
	self assert: ((project comments includes: aComment) = false)! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:32'!
testRemoveCommentFailure
	"Testing thar a user that is not a coordinator, admin or creator
	  can't remove a comment from a project"
	| aUser aComment |
	aUser := User new.
	aUser name: 'Mijail'.
	aUser login: 'mija'.
	aUser password: '12345'.
	aComment := Comment new.
	"variable user was created in the setUp method"
	aComment user: user.
	project addComment: aComment.
	"Testing that aComment was added properly to the project"
	self
		assert: (project comments includes: aComment).
	"Testing if aUser can remove aComment"	
	(OperationValidator
			modifyComment: aComment
			project: project
			user: aUser)
		ifTrue: [project removeComment: aComment.].
	"Testing that aComment wasn't removed"	
	self
		assert: (project comments includes: aComment)! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:35'!
testRemoveCommentUser
	"Testing that the creator of the comment can remove it"
	| aComment |
	aComment := Comment new.
	aComment user: user.
	project addComment: aComment.
	"Testing that aComment was properly added to the project"
	self
		assert: (project comments includes: aComment).
	"Testing the user can remove the comment"	
	(OperationValidator
			modifyComment: aComment
			project: project
			user: user)
		ifTrue: [project removeComment: aComment].
	"Testing if the comment was removed"	
	self assert: ((project comments includes: aComment)= false)! !
